import pandas as pd

# Treat Pandas/Numpy NaN, as well as strings containing only
# whitespace, as not-a-value.  Everything else is considered a value.
def is_na(value):
    return pd.isna(value) or (isinstance(value, str) and value.strip() == "")

# For convenience
def is_value(value):
    return not is_na(value)



import re

PII_REGEX = re.compile(r'(?i)(street|ein|address|zip|post_code|postcode|postal_code|location|locality|latitude|longitude|carrier_route|name|first_name|full_name|last_name|middle_name|suffix|phone|email|ssn|date_of_birth|date_of_death|contact|sms|court_case|sex_offender|deceased|owner|relation|gender|infoprivacy|tax|legal|business_name|businessname|companyname)')
